UpdateFolderDtoRequest class

Inheritance
  • Object
  • TWriteable
  • TWriteableId
  • UpdateFolderDtoRequest
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

UpdateFolderDtoRequest({String? name, String? emoji, String? path, bool? isActive})
UpdateFolderDtoRequest.fromJson(Map<String, dynamic> json)
factory

Properties

emoji String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique string identifier for this object.
no setteroverride
isActive bool?
final
name String?
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime
no setter

Methods

copyWith({String? name, String? emoji, String? path, bool? isActive}) UpdateFolderDtoRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the object to a Firestore-compatible map.
override
toString() String
A string representation of this object.
inherited
validate<T>() → TurboResponse<T>?
Validates the object's data before writing to Firestore.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fromJsonFactory → const UpdateFolderDtoRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(UpdateFolderDtoRequest instance)