AuthVars class

Auth-scoped API variables (id, userId, now). Pure Dart; no Flutter/Firestore dependencies. Use in DTO create factories for plx and plaza.

Inheritance

Constructors

AuthVars({required String id, required DateTime now, required String userId})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
finalinherited
now DateTime
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override