TSpawnConfig class

Configuration for spawning a set of promptable files and folders on disk.

Constructors

TSpawnConfig({required String root, required TPromptable systemPrompt, required List<TFolder> folders, required List<TFile> files})
const

Properties

files List<TFile>
final
folders List<TFolder>
final
hashCode int
The hash code for this object.
no setterinherited
root String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt TPromptable
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited