TSpawnable class abstract

Inheritance
Implementers

Constructors

TSpawnable(String name, {required String id, String? allowedTools, bool yolo = true, String? model, bool headless = true})
const

Properties

allowedTools String?
final
cascadeDescriptionToMetaData bool
finalinherited
cascadeNameToMetaData bool
finalinherited
description String?
finalinherited
fileName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headless bool
final
id String
final
jsonKey String
no setterinherited
mdFactory → TMdFactory<TWriteable>
Returns a function that builds a Markdown string from a JSON map.
no setterinherited
metaData TMetaData?
finalinherited
model String?
final
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt String
no setter
value String?
finalinherited
values List<String>?
finalinherited
xmlBuilder String Function(TWriteable writeable, bool includeMeta)?
Returns a function that builds an XML string from a JSON map.
finalinherited
xmlKey String
no setterinherited
yamlBuilder String Function(TWriteable writeable, bool includeMetaData)?
Returns a function that builds a YAML string from a JSON map.
finalinherited
yamlKey String
no setterinherited
yolo bool
final

Methods

mdFrontMatter() Map<String, dynamic>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ref({String? openRef, String? closeRef, required TBodyType bodyType}) String
inherited
refJson({String? openRef, String? closeRef}) String
inherited
refMd({String? openRef, String? closeRef}) String
inherited
refXml({String? openRef, String? closeRef}) String
inherited
refYaml({String? openRef, String? closeRef}) String
inherited
spawn({required String prompt, required TCliTool cliTool, String? conversationId}) String
toJson() Map<String, dynamic>
Converts the object to a Firestore-compatible map.
inherited
toMd({TMdFactory<TWriteable>? mdFactory, bool includeMetaData = true, int headingLevel = 1, KeyValueBuilderDef? titleBuilder, KeyValueBuilderDef? listItemBuilder, String metaDataKey = TSDefaults.metaDataKey, String emojiKey = TSDefaults.emojiKey, String nameKey = TSDefaults.nameKey, String descriptionKey = TSDefaults.descriptionKey, String valueKey = TSDefaults.valueKey, String valuesKey = TSDefaults.valuesKey, String itemsKey = TSDefaults.itemsKey}) String
Converts this object to a Markdown string.
inherited
toString() String
A string representation of this object.
inherited
toXml({bool includeMetaData = true, KeyValueBuilderDef? keyBuilder, KeyValueBuilderDef? listItemBuilder, String metaDataKey = TSDefaults.metaDataKey}) String
Converts this object to an XML string.
inherited
toYaml({bool includeMetaData = true, KeyValueBuilderDef? keyBuilder, String metaDataKey = TSDefaults.metaDataKey, KeyValueBuilderDef? listItemBuilder}) String
Converts this object to a YAML string.
inherited
validate<T>() → TurboResponse<T>?
Validates the object's data before writing to Firestore.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited