Role class

A role that can be assigned to a Persona or Agent, with specific expertise and capabilities.

Inheritance
Implementers
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

Role({required String name, TMetaData? metaData, TCliTool? cliTool, String? command, TPromptDelivery promptDelivery = TPromptDelivery.system, required String expertise, List<Activity>? activities, List<Checklist>? checklists, List<Instruction>? instructions, List<Template>? templates, List<Tool>? tools, List<Workflow>? workflows})
const
Role.fromJson(Map<String, dynamic> json)
factory

Properties

activities List<Activity>?
final
cascadeDescriptionToMetaData bool
finalinherited
cascadeNameToMetaData bool
finalinherited
checklists List<Checklist>?
final
cliTool TCliTool?
finalinherited
command String?
finalinherited
description String?
finalinherited
expertise String
final
fileName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
instructions List<Instruction>?
final
jsonKey String
no setterinherited
mdFactory → TMdFactory<TWriteable>
Returns a function that builds a Markdown string from a JSON map.
no setterinherited
metaData TMetaData?
finalinherited
name String
finalinherited
promptDelivery TPromptDelivery
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templates List<Template>?
final
tools List<Tool>?
final
value String?
finalinherited
values List<String>?
finalinherited
workflows List<Workflow>?
final
xmlBuilder String Function(TWriteable writeable, bool includeMeta)?
Returns a function that builds an XML string from a JSON map.
finalinherited
xmlKey String
no setterinherited
yamlBuilder String Function(TWriteable writeable, bool includeMetaData)?
Returns a function that builds a YAML string from a JSON map.
finalinherited
yamlKey String
no setterinherited

Methods

copyWith({String? name, TMetaData? metaData, String? expertise, List<Activity>? activities, List<Checklist>? checklists, List<Instruction>? instructions, List<Template>? templates, List<Tool>? tools, List<Workflow>? workflows}) Role
mdFrontMatter() Map<String, dynamic>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the object to a Firestore-compatible map.
override
toMd({TMdFactory<TWriteable>? mdFactory, bool includeMetaData = true, int headingLevel = 1, KeyValueBuilderDef? titleBuilder, KeyValueBuilderDef? listItemBuilder, String metaDataKey = TSDefaults.metaDataKey, String emojiKey = TSDefaults.emojiKey, String nameKey = TSDefaults.nameKey, String descriptionKey = TSDefaults.descriptionKey, String valueKey = TSDefaults.valueKey, String valuesKey = TSDefaults.valuesKey, String itemsKey = TSDefaults.itemsKey}) String
Converts this object to a Markdown string.
inherited
toString() String
A string representation of this object.
inherited
toXml({bool includeMetaData = true, KeyValueBuilderDef? keyBuilder, KeyValueBuilderDef? listItemBuilder, String metaDataKey = TSDefaults.metaDataKey}) String
Converts this object to an XML string.
inherited
toYaml({bool includeMetaData = true, KeyValueBuilderDef? keyBuilder, String metaDataKey = TSDefaults.metaDataKey, KeyValueBuilderDef? listItemBuilder}) String
Converts this object to a YAML string.
inherited
validate<T>() → TurboResponse<T>?
Validates the object's data before writing to Firestore.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited