TCliTool enum
Properties
- command → String
-
no setter
- commandsPath → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headless → String?
-
no setter
- homePath → String
-
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mcpsPath → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skillsPath → String
-
no setter
- subAgentsPath → String
-
no setter
- yolo → String
-
no setter
Methods
-
allowedTools(
String tools) → String -
mcpsConfig(
{required ConfigSource source}) → String -
model(
String? value) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resume(
String conversationId) → String -
spawn(
{required String request, String? conversationId, String? systemPrompt, String? allowedTools, bool yolo = true, String? model, bool headless = true}) → String -
systemPrompt(
String value) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited