TCliTool enum
Properties
- agentsFolderPath → String
-
no setter
- bareMcpFlag → String
-
no setter
- command → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headlessCommand
→ List<
String> ? -
Non-interactive launch shape for
SpawnDeliveryMode.headless.no setter - homeFolderPath → String
-
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mcpConfigFlag → String
-
no setter
- mcpFilePath → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - promptFolderPath → String
-
no setter
- requestFlag → String?
-
Flag that precedes the per-spawn request-file path in the
headless argv.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skillsFolderPath → String
-
no setter
- sourcesOverrideFlag → String
-
no setter
- systemPromptFlag → String
-
no setter
- yoloFlag → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited