Input class
The request side of a Step or Activity: a prose request describing
exactly what the step receives, plus optional structured context.
- Inheritance
-
- Object
- TWriteable
- TSerializable
- TPromptable
- Input
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
Properties
- cascadeDescriptionToMetaData → bool
-
finalinherited
- cascadeNameToMetaData → bool
-
finalinherited
-
context
→ List<
Context> ? -
final
- description → String?
-
finalinherited
- fileName → String
-
no setterinherited
-
goals
→ List<
EndGoal> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
Issue> ? -
final
- jsonKey → String
-
no setterinherited
-
mdFactory
→ TMdFactory<
TWriteable> -
Returns a function that builds a Markdown string from a JSON map.
no setterinherited
- metaData → TMetaData?
-
finalinherited
- name → String
-
finalinherited
-
parameters
→ Map<
String, Object> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
specs
→ List<
Spec> ? -
final
- value → String?
-
finalinherited
-
values
→ List<
String> ? -
finalinherited
- xmlBuilder → String Function(TWriteable writeable, bool includeMeta)?
-
Returns a function that builds an XML string from a JSON map.
finalinherited
- xmlKey → String
-
no setterinherited
- yamlBuilder → String Function(TWriteable writeable, bool includeMetaData)?
-
Returns a function that builds a YAML string from a JSON map.
finalinherited
- yamlKey → String
-
no setterinherited
Methods
-
mdFrontMatter(
) → Map< String, dynamic> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ref(
{String? openRef, String? closeRef, required TBodyType bodyType}) → String -
inherited
-
refJson(
{String? openRef, String? closeRef}) → String -
inherited
-
refMd(
{String? openRef, String? closeRef}) → String -
inherited
-
refXml(
{String? openRef, String? closeRef}) → String -
inherited
-
refYaml(
{String? openRef, String? closeRef}) → String -
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the object to a Firestore-compatible map.
override
-
toMd(
{TMdFactory< TWriteable> ? mdFactory, bool includeMetaData = true, int headingLevel = 1, KeyValueBuilderDef? titleBuilder, KeyValueBuilderDef? listItemBuilder, String metaDataKey = TSDefaults.metaDataKey, String emojiKey = TSDefaults.emojiKey, String nameKey = TSDefaults.nameKey, String descriptionKey = TSDefaults.descriptionKey, String valueKey = TSDefaults.valueKey, String valuesKey = TSDefaults.valuesKey, String itemsKey = TSDefaults.itemsKey}) → String -
Converts this object to a Markdown string.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toXml(
{bool includeMetaData = true, KeyValueBuilderDef? keyBuilder, KeyValueBuilderDef? listItemBuilder, String metaDataKey = TSDefaults.metaDataKey}) → String -
Converts this object to an XML string.
inherited
-
toYaml(
{bool includeMetaData = true, KeyValueBuilderDef? keyBuilder, String metaDataKey = TSDefaults.metaDataKey, KeyValueBuilderDef? listItemBuilder}) → String -
Converts this object to a YAML string.
inherited
-
validate<
T> () → TurboResponse< T> ? -
Validates the object's data before writing to Firestore.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited